pub struct TTCHeader<'a> {
pub(crate) data: FontData<'a>,
}Expand description
Fields
data: FontData<'a>Implementations
Sourceimpl<'a> TTCHeader<'a>
impl<'a> TTCHeader<'a>
pub const MIN_SIZE: usize
Sourcepub fn resolve_offset<O: Offset, R: FontRead<'a>>(
&self,
offset: O,
) -> Result<R, ReadError>
pub fn resolve_offset<O: Offset, R: FontRead<'a>>( &self, offset: O, ) -> Result<R, ReadError>
Resolve the provided offset from the start of this table.
Sourcepub fn offset_data(&self) -> FontData<'a>
pub fn offset_data(&self) -> FontData<'a>
Return a reference to this table’s raw data.
We use this in the compile crate to resolve offsets.
Sourcepub fn shape(&self) -> &Self
👎Deprecated: just use the base type directly
pub fn shape(&self) -> &Self
Return a reference to the table’s ‘Shape’ struct.
This is a low level implementation detail, but it can be useful in some cases where you want to know things about a table’s layout, such as the byte offsets of specific fields.
Sourcepub fn version(&self) -> MajorMinor
pub fn version(&self) -> MajorMinor
Major/minor version of the TTC Header
Sourcepub fn table_directory_offsets(&self) -> &'a [BigEndian<u32>]
pub fn table_directory_offsets(&self) -> &'a [BigEndian<u32>]
Array of offsets to the TableDirectory for each font from the beginning of the file
Sourcepub fn dsig_tag(&self) -> Option<u32>
pub fn dsig_tag(&self) -> Option<u32>
Tag indicating that a DSIG table exists, 0x44534947 (‘DSIG’) (null if no signature)
Sourcepub fn dsig_length(&self) -> Option<u32>
pub fn dsig_length(&self) -> Option<u32>
The length (in bytes) of the DSIG table (null if no signature)
Sourcepub fn dsig_offset(&self) -> Option<u32>
pub fn dsig_offset(&self) -> Option<u32>
The offset (in bytes) of the DSIG table from the beginning of the TTC file (null if no signature)
pub fn ttc_tag_byte_range(&self) -> Range<usize> ⓘ
pub fn version_byte_range(&self) -> Range<usize> ⓘ
pub fn num_fonts_byte_range(&self) -> Range<usize> ⓘ
pub fn table_directory_offsets_byte_range(&self) -> Range<usize> ⓘ
pub fn dsig_tag_byte_range(&self) -> Range<usize> ⓘ
pub fn dsig_length_byte_range(&self) -> Range<usize> ⓘ
pub fn dsig_offset_byte_range(&self) -> Range<usize> ⓘ